django-ftp-deploy
=================

django-ftp-deploy allows you to automatically deploy GIT repositories to FTP servers. You don't need to install git on the server!

.. warning:: Version 1.1 is completely rewritten and not back compatible with version 1.0


**Features:**

* Login Screen
* Services Dashboard (a service is one repository-to-ftp configuration)
* Manage Multiple Services
* Verification Services Configurations
* Repository Hook Management
* Dynamic Loading of Repository list
* Restore Failed Deploys
* Email Notifications per service
* Statistics of Deployments
* Deployment Logs


Supported GIT repositories:

* Bitbucket
* Github (planned)


Documentation
-------------

`Read The Docs <http://django-ftp-deploy.readthedocs.org/en/latest/>`_. 